import {render} from "@testing-library/react-native";
import {Card} from "@/components/Card";
import {AppointmentCard} from "@/components/AppointmentCard";

jest.mock('@expo/vector-icons', () => {
    return {
        MaterialIcons: jest.fn(() => null),
    };
});

jest.mock('expo-font', () => {
    return {
        Font: {
            isLoaded: jest.fn(() => true),
        },
    };
});

describe("Test Components", () => {
    it("renders Card", () => {
        const tree = render(
            <Card
                item1={"Item 1"}
                item2={"Item 2"}
                item3={"Item 3"}
                quantity={"Quantity"}
                label={""}
            />
        ).toJSON();
        expect(tree).toMatchSnapshot();
    });

    it("renders AppointmentCard", () => {
        const tree = render(
            <AppointmentCard
                data1={"Data 1"}
                data2={"Data 2"}
                item1={"Item 1"}
                item2={"Item 2"}
                item3={"Item 3"}
            />
        ).toJSON();
        expect(tree).toMatchSnapshot();
    });

    it("test AppointmentCard props", () => {
        const {getByText} = render(
            <AppointmentCard
                data1={"Data 1"}
                data2={"Data 2"}
                item1={"Item 1"}
                item2={"Item 2"}
                item3={"Item 3"}
            />
        );
        expect(getByText("Data 1")).toBeTruthy();
        expect(getByText("Data 2")).toBeTruthy();
        expect(getByText("Item 1")).toBeTruthy();
        expect(getByText("Item 2")).toBeTruthy();
        expect(getByText("Item 3")).toBeTruthy();
    });

    it("test Card props", () => {
        const {getByTestId} = render(
            <Card
                item1={"Item1"}
                item2={"Item2"}
                item3={"Item3"}
                quantity={"Quantity"}
            />
        );

        expect(getByTestId("card-container")).toBeTruthy();
        expect(getByTestId("card-text1").props.children).toBe("Item1");
        expect(getByTestId("card-text2").props.children).toBe("Item2");
        expect(getByTestId("card-text3").props.children).toBe("Item3");
        expect(getByTestId("card-quantity").props.children).toBe("Quantity");
    });
})