import {handleLogin, handleSignUp} from "@/constants/handleAuthentication";
import fetchMock from 'jest-fetch-mock';
import 'formdata-polyfill';
import {insertSymptoms} from "@/constants/insertData";

fetchMock.enableMocks();
describe("Test Insert Data", () => {
    console.log = jest.fn();
    const patientID = jest.fn();
    const setPatientID = jest.fn();
    const setDoctorID = jest.fn();
    const setLoading = jest.fn();
    const setConfirmed = jest.fn();
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it("No Email Login", () => {
        handleLogin("","Sp//der", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Email is required.\nEmail must be of the format: anything@example.com");
    });
    it("No Password Login", () => {
        handleLogin("tom.holland@example.com","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Password is required.");
    });
    it("No Email and Password Login", () => {
        handleLogin("","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Email is required.\nPassword is required.\nEmail must be of the format: anything@example.com");
    });
    it("Incorrect Data Login", () => {
        handleLogin("1","1", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Email must be of the format: anything@example.com");
    });
    it("Login Success", () => {
        handleLogin("tom.holland@example.com","Sp//der", setPatientID, setDoctorID,setLoading);
        expect(console.log).not.toHaveBeenCalled();
    });
    it("No Name SignUp", () => {
        handleSignUp("","TheLegend27","raid@shadows.com","Ra1dSh4d0w","05549372963","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Name is required.");
    });
    it("No Username SignUp", () => {
        handleSignUp("Legend","","raid@shadows.com","Ra1dSh4d0w","05549372963","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Username is required.");
    });
    it("No Email SignUp", () => {
        handleSignUp("Legend","TheLegend27","","Ra1dSh4d0w","05549372963","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Email is required.\nEmail must be of the format: anything@example.com");
    });
    it("No Password SignUp", () => {
        handleSignUp("Legend","TheLegend27","raid@shadows.com","","05549372963","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Password is required.");
    });
    it("No Phone Number SignUp", () => {
        handleSignUp("Legend","TheLegend27","raid@shadows.com","Ra1dSh4d0w","","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Phone-number is required.\nPhone-number must be one of the following formats: +012345678912, 0123456789, +01234567890, 123-123-1234");
    });
    it("Doctor Role - No Doctor Type SignUp", () => {
        handleSignUp("Legend","TheLegend27","raid@shadows.com","Ra1dSh4d0w","05549372963","","doctor", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Doctor Type is required.");
    });
    it("Incorrect Data SignUp", () => {
        handleSignUp("1","1","1","1","1","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).toHaveBeenCalledWith("Email must be of the format: anything@example.com\nPhone-number must be one of the following formats: +012345678912, 0123456789, +01234567890, 123-123-1234"
    );
    });
    it("SignUp Success", () => {
        handleSignUp("Legend","TheLegend27","raid@shadows.com","Ra1dSh4d0w","05549372963","","", setPatientID, setDoctorID,setLoading);
        expect(console.log).not.toHaveBeenCalled();
    });
    it("No Name, Insert Symptoms", () => {
        insertSymptoms(patientID, "", "Persistent throbbing at the front of the skull",1, new Date(), setConfirmed);
        expect(console.log).toHaveBeenCalledWith("Symptom name is required.");
    });
    it("No Description, Insert Symptoms", () => {
        insertSymptoms(patientID, "Headache", "",1, new Date(), setConfirmed);
        expect(console.log).toHaveBeenCalledWith("Symptom description is required.");
    });
    it("Incorrect Severity, Insert Symptoms", () => {
        insertSymptoms(patientID, "Headache", "Persistent throbbing at the front of the skull", "", new Date(), setConfirmed);
        expect(console.log).toHaveBeenCalledWith("Symptom severity is required.");
    });
    it("No Start Date, Insert Symptoms", () => {
        insertSymptoms(patientID, "Headache", "Persistent throbbing at the front of the skull",1, "", setConfirmed);
        expect(console.log).toHaveBeenCalledWith("Start date is required.");
    });
    it("Incorrect Data Insert Symptoms", () => {
        insertSymptoms(patientID, 1,1,"", 1, setConfirmed);
        expect(console.log).toHaveBeenCalledWith("Symptom severity is required.");
    });
    it("Insert Symptoms Success", () => {
        insertSymptoms(patientID, "Headache", "Persistent throbbing at the front of the skull", 1, new Date(), setConfirmed);
        expect(console.log).not.toHaveBeenCalled();
    });
});