import {GestureHandlerRootView} from "react-native-gesture-handler";
import {Drawer} from 'expo-router/drawer';
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import {useColorScheme, useWindowDimensions} from "react-native";
import {PatientProvider} from "@/hooks/usePatient";
import {DoctorProvider} from "@/hooks/useDoctor";
import {Colors} from "@/constants/Colors";
import {StatusBar} from "expo-status-bar";

export default function DrawerLayout() {
    const {width} = useWindowDimensions();
    const drawerWidth = width * 0.55
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;

    let debugMode = false;
    let drawer = debugMode ? {display: 'block'} : {display: 'none'}

    function renderIcon(name, size, themeStyle) {
        return (
            <MaterialIcons name={name} size={size} style={themeStyle} color={themeStyle.color}/>
        )
    }

    const screens = [
        {name: "index", label: "Index", icon: "start", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "login", label: "Login", icon: "login", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "signup", label: "Signup", icon: "app-registration", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "profile", label: "User", icon: "account-circle"},
        {name: "education", label: "Education", icon: "school"},
        {name: "notifications", label: "Notifications", icon: "notifications"},
        {name: "medication", label: "Medications", icon: "medication"},
        {name: "documents", label: "Documents", icon: "import-contacts"},
        {name: "location", label: "Location", icon: "map"},
        {name: "contacts", label: "Contacts", icon: "phone"},
        {name: "appointments", label: "Appointments", icon: "access-time-filled"},
        {name: "symptoms", label: "Symptoms", icon: "assessment"},
        {name: "home", label: "Home", icon: "home"},
        {name: "+not-found", label: "Not Found", icon: "home", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "doctor", label: "Doctor", icon: "masks", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "doctorUpdate", label: "Doctor", icon: "masks", headerShown: debugMode, drawerItemStyle: drawer},
        {name: "doctorInsert", label: "Doctor", icon: "masks", headerShown: debugMode, drawerItemStyle: drawer},
    ];

    return (
        <DoctorProvider>
            <PatientProvider>
                <StatusBar backgroundColor={themeStyle.backgroundColor} style={useColorScheme() === "dark" ? "light" : "dark"} />
                <GestureHandlerRootView style={{flex: 1, backgroundColor: themeStyle.backgroundColor}}>
                    <Drawer
                        screenOptions={{
                            headerStyle: {
                                backgroundColor: themeStyle.backgroundColor,
                                height: 80,
                            },
                            headerTitleStyle: {
                                fontSize: 26,
                                fontWeight: 'bold',
                                textDecorationLine: 'underline',
                                color: themeStyle.color,
                            },
                            headerTintColor: themeStyle.color,
                            drawerStyle: {
                                width: drawerWidth,
                                backgroundColor: themeStyle.backgroundColor,
                            },
                        }}
                    >
                        {screens.map(({name, label, icon, headerShown, drawerItemStyle}) => (
                            <Drawer.Screen
                                key={name}
                                name={name}
                                options={{
                                    title: label,
                                    drawerLabel: label,
                                    drawerLabelStyle: {
                                      color: themeStyle.color,
                                    },
                                    drawerIcon: ({size}) => renderIcon(icon, size, themeStyle),
                                    headerShown: headerShown ?? true,
                                    swipeEnabled: headerShown ?? true,
                                    drawerItemStyle: drawerItemStyle ?? {display: 'block'},
                                }}
                            />
                        ))}
                    </Drawer>
                </GestureHandlerRootView>
            </PatientProvider>
        </DoctorProvider>
    );
}
