import {ActivityIndicator, FlatList, useColorScheme, View} from "react-native";
import {SearchBar} from "@/components/SearchBar";
import React, {useEffect, useState} from "react";
import {Colors} from "@/constants/Colors";
import {ContactCard} from "@/components/ContactCard";
import {usePatient} from "@/hooks/usePatient";
import {useFunction} from "@/constants/fetchData";
import {searchContacts} from "@/constants/searchData";

export default function Contacts() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const { patientID } = usePatient();
    const [data, setData] = useState([]);
    useFunction(patientID, setData, "getDoctors");

    const [search, setSearch] = useState("");
    const [loading, setLoading] = useState(true);
    const [doctorName, setDoctorName] = useState();
    const [doctorType, setDoctorType] = useState();
    const [phoneNumber, setPhoneNumber] = useState();

    useEffect(() => {
        setSearch("");
    }, [patientID]);

    return (
        <FlatList
            ListHeaderComponent={
            <>
                <SearchBar
                    icon={true}
                    placeholder={"Search Contact Name."}
                    value={search}
                    onChangeText={setSearch}
                    onBlur={() => searchContacts(search, setLoading, setDoctorName, setDoctorType, setPhoneNumber)}
                />

                {search ? (
                    <ActivityIndicator
                        size={"small"}
                        animating={loading}
                    />
                ): null}

                {search && doctorName && doctorType && phoneNumber ? (
                    <>
                        <ContactCard
                            image={"access-time-filled"}
                            item1={doctorName}
                            item2={doctorType}
                            phoneNumber={phoneNumber}
                        />
                        <View style={themeStyle.divider} />
                    </>
                ) : null}
            </>
            }
            nestedScrollEnabled={true}
            data={data}
            style={themeStyle}
            renderItem={({ item }) => (
                search && doctorName && item["doctorName"] === doctorName ? null : (
                    <ContactCard
                        image={"access-time-filled"}
                        item1={item["doctorName"]}
                        item2={item["doctorType"]}
                        item3={item["desc"]}
                        phoneNumber={item["phoneNumber"]}
                    />
                )
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    );
}
