import {Platform, ScrollView, StyleProp, useColorScheme, ViewStyle} from "react-native";
import React, {useState} from "react";
import {logOutDoctor, pushDoctor, pushDoctorUpdate} from "@/constants/pushUser";
import {useDoctor} from "@/hooks/useDoctor";
import {MaskedTextInput} from "react-native-mask-text";
import {
    getPatientID,
    insertAppointment,
    insertDocument,
    insertMedication,
    insertNotifs
} from "@/constants/doctorInsertFunctions";
import {DoctorNav} from "@/components/DoctorNav";
import {Colors} from "@/constants/Colors";
import {SearchBar} from "@/components/SearchBar";
import StyledButton from "@/components/StyledButton";

function handlePatientID(patientName){
    if(patientName) {
        getPatientID(patientName).then((r) => {
            console.log("Select Successful: ", r);
            return r;
        }).catch((error) => {
            console.error("Select Failed: ", error);
        });
    }
}

function handleInsert(patientName, functionName, ...params){
    let patientID = getPatientID(patientName);
    console.log("Patient ID from handleInsert in doctorInsert: ", patientID);
    insertParams(functionName, patientID, ...params);
}

function insertParams(functionName, ...params){
    if(params.length > 0) {
        functionName(...params).then((r) => {
            alert("Insert Successful");
            console.log("Insert Successful: ", r);
        }).catch((error) => {
            alert("Insert Failed: " + error.message);
            console.error("Insert Failed: ", error);
        });
    }
}

export default function DoctorInsert() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    let barHeight = Platform ? 50 : 80;
    const [search, setSearch] = useState();
    const {doctorID, setDoctorID} = useDoctor();

    const [doc, setDoc] = useState('');

    const [appointmentDate, setAppointmentDate] = useState('');
    const [appointmentTime, setAppointmentTime] = useState('');
    const [title, setTitle] = useState('');
    const [appointDescription, setAppointDescription] = useState('');

    const [medicationName, setMedicationName] = useState('');
    const [strength, setStrength] = useState('');
    const [type, setType] = useState('');
    const [frequency, setFrequency] = useState('');
    const [timeOfDay, setTimeOfDay] = useState('');
    const [medDescription, setMedDescription] = useState('');

    const [notificationTime, setNotificationTime] = useState('');
    const [subject, setSubject] = useState('');
    const [notifDescription, setNotifDescription] = useState('');

    function forceDate(text) {
        // Regex for YYYY-MM-DD or DD/MM/YYYY
        const dateRegex = /^(?:\d{4}-\d{2}-\d{2}|\d{2}\/\d{2}\/\d{4})$/;

        if (!dateRegex.test(text)) {
            alert("Enter a valid date (YYYY-MM-DD or DD/MM/YYYY)");
        }
    }

    function forceTime(text){
        const timeRegex = /^([01]?[0-9]|2[0-3]):([0-5][0-9])(:[0-5][0-9])?$/;

        if (!timeRegex.test(text)) {
            alert("Enter a valid time (HH:MM or HH:MM:SS)");
        }
    }

    const viewStyle: StyleProp<ViewStyle> = {
        backgroundColor: themeStyle.backgroundColor,
        color: themeStyle.color,
        paddingTop: "10%",
    }

    return (
        <ScrollView contentContainerStyle={viewStyle}>
            <SearchBar
                icon={true}
                placeholder={"Search Patient Name."}
                value={search}
                onChangeText={() => setSearch}
            />

            <DoctorNav
                buttonText1={"Go to Home"}
                buttonFunction1={pushDoctor}
                buttonStyle1={{flexGrow: 1, backgroundColor: themeStyle.selectButton.backgroundColor}}

                buttonText2={"Sign Out"}
                buttonFunction2={() => logOutDoctor(setDoctorID)}
                buttonStyle2={{flexGrow: 1, backgroundColor: themeStyle.cancelButton.backgroundColor}}

                buttonText3={"Go to Update Data"}
                buttonFunction3={pushDoctorUpdate}
                buttonStyle3={{backgroundColor: themeStyle.moveButton.backgroundColor}}
            />

            <SearchBar placeholder="Enter Document" value={doc} onChangeText={setDoc} />
            <StyledButton
                text={"Insert Document Data"}
                onPress={() => handleInsert(handlePatientID, search, insertDocument, doctorID, doc)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
            />

            <MaskedTextInput
                mask="9999-99-99"
                placeholder="Enter Appointment Date."
                keyboardType="numeric"
                value={appointmentDate}
                onChangeText={setAppointmentDate}
                onBlur={() => forceDate(appointmentDate)}
                style={style(barHeight).searchBarContainer}
            />
            <MaskedTextInput
                mask="99:99:99"
                placeholder="Enter Appointment Time."
                keyboardType="numeric"
                value={appointmentTime}
                onChangeText={setAppointmentTime}
                onBlur={() => forceTime(appointmentTime)}
                style={style(barHeight).searchBarContainer}
            />
            <SearchBar placeholder="Enter Title" value={title} onChangeText={setTitle} />
            <SearchBar placeholder="Enter Description" value={appointDescription} onChangeText={setAppointDescription} />
            <StyledButton
                text="Insert Appointment Data"
                onPress={() => handleInsert(handlePatientID, search, insertAppointment, doctorID, appointmentDate,appointmentTime,title,appointDescription)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
            />

            <SearchBar placeholder="Enter Medication Name" value={medicationName} onChangeText={setMedicationName} />
            <SearchBar placeholder="Enter Strength" value={strength} onChangeText={setStrength} />
            <SearchBar placeholder="Enter Type" value={type} onChangeText={setType} />
            <SearchBar placeholder="Enter Frequency" value={frequency} onChangeText={setFrequency} />
            <MaskedTextInput
                mask="99:99:99"
                placeholder="Enter Time of Day"
                keyboardType="numeric"
                value={timeOfDay}
                onChangeText={setTimeOfDay}
                onBlur={() => forceTime(timeOfDay)}
                style={style(barHeight).searchBarContainer}
            />
            <SearchBar placeholder="Enter Description" value={medDescription} onChangeText={setMedDescription} />
            <StyledButton
                text="Insert Medication Data"
                onPress={() => handleInsert(handlePatientID, search, insertMedication, doctorID, medicationName, strength, type, frequency, timeOfDay, medDescription)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
            />

            <MaskedTextInput
                mask="99:99:99"
                placeholder="Enter Notification Time"
                keyboardType="numeric"
                value={notificationTime}
                onChangeText={setNotificationTime}
                onBlur={text => forceTime(text)}
                style={style(barHeight).searchBarContainer}
            />
            <SearchBar placeholder="Enter Subject" value={subject} onChangeText={setSubject} />
            <SearchBar placeholder="Enter Description" value={notifDescription} onChangeText={setNotifDescription} />
            <StyledButton
                text="Insert Notification Data."
                onPress={() => handleInsert(handlePatientID, search, insertNotifs, doctorID, notificationTime,subject,notifDescription)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
            />
            </ScrollView>
    );
}

const style = (barHeight) => ({
    searchBarContainer: {
        flexDirection: 'row',
        alignItems: 'center',
        borderRadius: 20,
        borderWidth: 1,
        margin: "2%",
        height: barHeight,
        paddingHorizontal: 10,
    },
});