import {SectionList, StyleProp, StyleSheet, Text, TextStyle, useColorScheme, View} from "react-native";
import {ListData} from "@/components/ListData";
import {Colors} from "@/constants/Colors";
import {ListDocuments} from "@/components/ListDocuments";
import React from "react";
import {ListAppoints} from "@/components/ListAppoints";
import {ListNotifs} from "@/components/ListNotifs";
// https://venngage.com/tools/accessible-color-palette-generator

export default function Home() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;

    const sections = [
        {
            title: 'Symptoms',
            data: [{functionName: "getSymptoms",
                image: "assessment",
                dataPoint1: "symptomName",
                dataPoint2: "symptomDescription",
                quantity: "symptomSeverity",
                label: "Severity",
            }],
        },
        {
            title: 'Notifications',
            data: [{functionName: "getNotifications",
                image: "notifications",
                date: "notificationDate",
                time: "notificationTime",
                dataPoint1: "subject",
                dataPoint2: "description",
            }],
        },
        {
            title: 'Medications',
            data: [{ functionName: "getMedications",
                image: "medication",
                dataPoint1: "medicationName",
                dataPoint2: "strength",
                dataPoint3: "type",
                quantity: "quantityAvailable",
                label: "Reorder",
            }],
        },
        {
            title: 'Appointments',
            data: [{ functionName: "getAppointments",
                image: "access-time-filled",
                column1: "appointmentDate",
                column2: "appointmentTime",
                dataPoint1: "title",
                dataPoint2: "description",
                dataPoint3: "location",
            }],
        },
        {
            title: 'Documents',
            data: [{ functionName: "getDocuments",
                image: "import-contacts",
                dataPoint1: "documentTitle",
                dataPoint2: "documentDescription",
                dataPoint3: "documentFile",
                quantity: "followUp",
                label: "Follow Up",
            }],
        },
    ];

    const titleStyle: StyleProp<TextStyle> = {
        fontSize: 18,
        color: themeStyle.color,
        fontWeight: "bold",
        textDecorationLine: "underline",
    };

    return (
        <SectionList
            stickySectionHeadersEnabled={true}
            style={[style.page, themeStyle]}
            sections={sections}
            renderItem={({ item }) => {
                if(item.functionName === "getDocuments") {
                    return (
                        <ListDocuments
                            image={item.image}
                            dataPoint1={item.dataPoint1}
                            dataPoint2={item.dataPoint2}
                            dataPoint3={item.dataPoint3}
                            quantity={item.quantity}
                            label={item.label}
                            functionName={item.functionName}
                        />
                    );
                } else if (item.functionName === "getAppointments") {
                    return(
                        <ListAppoints
                            image={item.image}
                            column1={item.column1}
                            column2={item.column2}
                            dataPoint1={item.dataPoint1}
                            dataPoint2={item.dataPoint2}
                            dataPoint3={item.dataPoint3}
                            functionName={item.functionName}
                        />
                    )
                } else if (item.functionName === "getNotifications") {
                    return(
                        <ListNotifs
                            image={item.image}
                            date={item.date}
                            time={item.time}
                            dataPoint1={item.dataPoint1}
                            dataPoint2={item.dataPoint2}
                            dataPoint3={item.dataPoint3}
                            functionName={item.functionName}
                        />
                    )
                }
                else {
                    return(
                        <ListData
                            image={item.image}
                            functionName={item.functionName}
                            dataPoint1={item.dataPoint1}
                            dataPoint2={item.dataPoint2}
                            dataPoint3={item.dataPoint3}
                            quantity={item.quantity}
                            label={item.label}
                        />
                    );
                }
            }}
            renderSectionHeader={({ section }) => (
                <View style={[themeStyle, style.headerContainer]}>
                    <Text style={titleStyle}>
                        {section.title}
                    </Text>
                </View>
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    );
}

const style = StyleSheet.create({
    page: {
        paddingTop: 5,
        paddingLeft: 5,
        paddingRight: 5,
    },
    headerContainer: {
        padding: 10,
    },
});