import {ActivityIndicator, SafeAreaView, StyleProp, useColorScheme, View, ViewStyle} from "react-native";
import React, {useState} from "react";
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import {monitorUser, pushRegister} from "@/constants/pushUser";
import {styles} from "@/constants/styles";
import {usePatient} from "@/hooks/usePatient";
import {useDoctor} from "@/hooks/useDoctor";
import {Colors} from "@/constants/Colors";
import {handleLogin} from "@/constants/handleAuthentication";
import StyledButton from "@/components/StyledButton";
import {SearchBar} from "@/components/SearchBar";

export default function Login() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const [loading, setLoading] = useState(false);
    const [email, setEmail] = useState("");
    const [password, setPassword] = useState("");

    const { setPatientID, patientID } = usePatient();
    const { setDoctorID, doctorID } = useDoctor();

    monitorUser(patientID, doctorID);
    const viewStyle: StyleProp<ViewStyle> = {
        backgroundColor: themeStyle.backgroundColor,
        color: themeStyle.color,
        flex: 1,
        paddingTop: "10%",
    }
    return (
        <SafeAreaView style={viewStyle}>
            <SearchBar placeholder="Email" textContentType={"emailAddress"} value={email} onChangeText={setEmail} style={themeStyle.textInput}/>
            <SearchBar placeholder="Password" textContentType={"password"} secureTextEntry={true} value={password} onChangeText={setPassword} style={themeStyle.textInput}/>
            <StyledButton
                onPress={() => handleLogin(email, password, setPatientID, setDoctorID, setLoading)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
                text={"Login"}
            />

            {loading ? (
                <ActivityIndicator
                    size={"small"}
                    animating={loading}
                />
            ): null}

            <View style={styles.adjustMiddle}>
                <MaterialIcons name={"app-registration"} size={50} style={{ alignSelf: "center" }} />
                <StyledButton
                    onPress={pushRegister}
                    buttonStyle={{backgroundColor: themeStyle.moveButton.backgroundColor}}
                    textStyle={{color: themeStyle.moveButton.color}}
                    text={"Sign Up"}
                />
            </View>
        </SafeAreaView>
    );
}
