import React, {useEffect, useState} from "react";
import {ActivityIndicator, FlatList, useColorScheme, View} from "react-native";
import {SearchBar} from "@/components/SearchBar";
import {Colors} from "@/constants/Colors";
import {Card} from "@/components/Card";
import {usePatient} from "@/hooks/usePatient";
import {searchMeds} from "@/constants/searchData";
import {useFunction} from "@/constants/fetchData";

export default function Medication() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const {patientID } = usePatient();
    const [data, setData] = useState([]);
    useFunction(patientID, setData, "getMedications");

    const [search, setSearch] = useState("");
    const [loading, setLoading] = useState(true);
    const [medicationName, setMedicationName] = useState();
    const [strength, setStrength] = useState();
    const [type, setType] = useState();
    const [quantity, setQuantity] = useState();

    useEffect(() => {
        if(!patientID){
            setSearch("");
        }
    }, [patientID]);

    return (
        <FlatList
            ListHeaderComponent={
            <>
                <SearchBar
                    icon={true}
                    placeholder={"Search Medication Name."}
                    value={search}
                    onChangeText={setSearch}
                    onBlur={() => searchMeds(patientID, search, setLoading, setMedicationName, setStrength, setType, setQuantity)}
                />

                {search ? (
                    <ActivityIndicator
                        size={"small"}
                        animating={loading}
                    />
                ): null}

                {search && medicationName && strength && type && quantity ? (
                    <>
                        <Card
                            image={"medication"}
                            item1={medicationName}
                            item2={strength}
                            item3={type}
                            quantity={quantity}
                            label={"Reorder"}
                        />
                        <View style={themeStyle.divider} />
                    </>
                ) : null}
            </>
            }
            nestedScrollEnabled={true}
            data={data}
            style={themeStyle}
            renderItem={({ item }) => (
                search && medicationName && item["medicationName"] === medicationName ? null : (
                    <Card
                        image={"medication"}
                        item1={item["medicationName"]}
                        item2={item["strength"]}
                        item3={item["type"]}
                        quantity={item["quantityAvailable"]}
                        label={"Reorder"}
                    />
                )
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    );
}
