import {ActivityIndicator, FlatList, useColorScheme, View} from "react-native";
import {SearchBar} from "@/components/SearchBar";
import React, {useEffect, useState} from "react";
import {Colors} from "@/constants/Colors";
import {usePatient} from "@/hooks/usePatient";
import {Card} from "@/components/Card";
import {searchNotifs} from "@/constants/searchData";
import {useFunction} from "@/constants/fetchData";

export default function Notifications() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const {patientID} = usePatient();
    const [data, setData] = useState([]);
    useFunction(patientID, setData, "getNotifications");

    const [search, setSearch] = useState("");
    const [loading, setLoading] = useState(true);
    const [notificationTime, setNotificationTime] = useState();
    const [subject, setSubject] = useState("");
    const [description, setDescription] = useState("");

    useEffect(() => {
        if (!patientID) {
            setSearch("");
        }
    }, [patientID]);

    return (
        <FlatList
            ListHeaderComponent={
            <>
                <SearchBar
                    icon={true}
                    placeholder={"Search Notification Subject."}
                    value={search}
                    onChangeText={setSearch}
                    onBlur={() => {
                        if(search !== ""){
                            searchNotifs(patientID, search, setLoading, setNotificationTime, setSubject, setDescription)
                        }
                    }}
                />

                {search ? (
                    <ActivityIndicator
                        size={"small"}
                        animating={loading}
                    />
                ): null}

                {search && notificationTime && subject && description ? (
                    <>
                        <Card
                            image={"notifications"}
                            item1={notificationTime}
                            item2={subject}
                            item3={description}
                        />
                        <View style={themeStyle.divider} />
                    </>
                ) : null}
            </>
            }
            nestedScrollEnabled={true}
            style={themeStyle}
            data={data}
            renderItem={({ item }) => (
                search && subject && item["subject"] === subject ? null : (
                    <Card
                        image={"notifications"}
                        item1={item["notificationTime"]}
                        item2={item["subject"]}
                        item3={item["description"]}
                    />
                )
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    );
}
