import {Image, Pressable, useColorScheme, View} from "react-native";
import {logOutPatient} from "@/constants/pushUser";
import {usePatient} from "@/hooks/usePatient";
import {ListData} from "@/components/ListData";
import React, {useEffect, useState} from "react";
import {Colors} from "@/constants/Colors";
import {MediaModal} from "@/components/MediaModal";
import StyledButton from "@/components/StyledButton";
import {convertBase64ToUri} from "@/constants/fileConversion";
import {fetchRequest} from "@/constants/fetchData";


async function getAvatar(patientID, setImage) {
    const formData = new FormData();
    formData.append("action", "getAvatar");
    formData.append("patientID", patientID);

    const response = await fetch(
        "https://devweb2023.cis.strath.ac.uk/~qrb21125/Project/constants/project.php",
        {
            method: "POST",
            body: formData,
        }
    );

    let data = await response.json();
    if (data && data.data["avatarPicture"]) {
        let uri = convertBase64ToUri(data.data["avatarPicture"]);
        setImage(uri);
    }
}

async function insertAvatar(patientID, avatarPicture) {
    const formData = new FormData();
    formData.append("action", "updateAvatar");
    formData.append("patientID", patientID);
    formData.append("avatarPicture", {
        uri: avatarPicture,
        type: "image/jpeg",
        name: "avatarPicture",
    });
    return await fetchRequest(formData);
}

async function getAvatarImage(patientID, setImage): Promise<string> {
    await getAvatar(patientID, setImage);
}

export default function Profile() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const { patientID, setPatientID} = usePatient();
    const [image, setImage] = useState<string | null>(null);
    const [isModalOpen, setIsModalOpen] = useState(false);

    useEffect(() => {
        console.log('Logged out, patientID reset.', patientID);
    }, [patientID]);
    useEffect(() => {
        if (!image) setIsModalOpen(false);
    }, [image]);

    useEffect(() => {
        if(image) {
            insertAvatar(patientID, image).then((response) => {
                if(!response.success){
                    console.log("Failed to insert avatar: ", response.message);
                    return;
                }
                console.log("Successfully inserted avatar: ", response.data);
            });
        }
    }, [image]);

    useEffect(() => {
        getAvatarImage(patientID, setImage).then(_ => {});
    }, [patientID]);

    return (
        <View style={themeStyle}>
            <Pressable style={{alignSelf: "center", height: 100, width: 100}} onPress={() => setIsModalOpen(true)} >
                <Image
                    source={image ? { uri: image } : require('@/assets/images/placeholder.png')}
                    style={{ alignSelf: 'center', marginBottom: 10, width: 100, height: 100, borderWidth: 1, borderRadius: 50 }}
                />
            </Pressable>

            <ListData
                dataPoint1={"patientName"}
                dataPoint2={"userName"}
                dataPoint3={"email"}
                functionName={"getPatient"}
            />

            <StyledButton
                onPress={() => logOutPatient(patientID, setPatientID)}
                buttonStyle={{backgroundColor: themeStyle.cancelButton.backgroundColor}}
                textStyle={{color: themeStyle.cancelButton.color}}
                text={"Sign Out"}
            />

            <MediaModal
                image={image}
                isModalOpen={isModalOpen}
                setIsModalOpen={setIsModalOpen}
                setImage={setImage}
            />
        </View>
    );
}