import {ActivityIndicator, SafeAreaView, StyleProp, useColorScheme, View, ViewStyle} from "react-native";
import React, {useState} from 'react';
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import {monitorUser, pushLogin} from "@/constants/pushUser";
import {styles} from "@/constants/styles";
import {usePatient} from "@/hooks/usePatient";
import {Colors} from "@/constants/Colors";
import {useDoctor} from "@/hooks/useDoctor";
import RadioGroup from "react-native-radio-buttons-group";
import StyledButton from "@/components/StyledButton";
import {handleSignUp} from "@/constants/handleAuthentication";
import {SearchBar} from "@/components/SearchBar";

export default function Signup() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const [loading, setLoading] = useState(false);
    const [name, setName] = useState('');
    const [userName, setUserName] = useState('');
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [phoneNumber, setPhoneNumber] = useState('');
    const [doctorType, setDoctorType] = useState('');

    const { patientID, setPatientID } = usePatient();
    const { doctorID, setDoctorID } = useDoctor();

    const [role, setRole] = useState("patient");

    const radioButtons = [
        { id: "patient", label: "Patient", value: "patient" },
        { id: "doctor", label: "Doctor", value: "doctor" }
    ];

    monitorUser(patientID, doctorID);
    const viewStyle: StyleProp<ViewStyle> = {
        backgroundColor: themeStyle.backgroundColor,
        color: themeStyle.color,
        flex: 1,
        paddingTop: "10%",
    }
    return (
        <SafeAreaView style={viewStyle}>
            <SearchBar textContentType={"name"} placeholder="Enter Name" value={name} onChangeText={setName} style={themeStyle.textInput}/>
            <SearchBar textContentType={"username"} placeholder="Enter Username" value={userName} onChangeText={setUserName} style={themeStyle.textInput}/>
            <SearchBar textContentType={"emailAddress"} placeholder="Enter Email" value={email} onChangeText={setEmail} style={themeStyle.textInput}/>
            <SearchBar textContentType={"password"} placeholder="Enter Password" secureTextEntry={true} value={password} onChangeText={setPassword} style={themeStyle.textInput}/>
            <SearchBar textContentType={"telephoneNumber"} placeholder="Enter Phone Number" value={phoneNumber} onChangeText={setPhoneNumber} style={themeStyle.textInput}/>
            <RadioGroup
                radioButtons={radioButtons}
                onPress={(selected) => {
                    setRole(selected.toString());
                }}
                selectedId={role}
                layout="row"
            />
            {role === "doctor" && (
                <SearchBar placeholder="Enter Doctor Type" value={doctorType} onChangeText={setDoctorType} style={themeStyle.textInput}/>
            )}
            <StyledButton
                onPress={() => handleSignUp(name, userName, email, password, phoneNumber, doctorType, role, setPatientID, setDoctorID, setLoading)}
                buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                textStyle={{color: themeStyle.confirmButton.color}}
                text={"Sign Up"}
            />

            {loading ? (
                <ActivityIndicator
                    size={"small"}
                    animating={loading}
                />
            ): null}

            <View style={styles.adjustMiddle}>
                <MaterialIcons name={"login"} size={50} style={{alignSelf: "center"}}/>
                <StyledButton
                    onPress={pushLogin}
                    buttonStyle={{backgroundColor: themeStyle.moveButton.backgroundColor}}
                    textStyle={{color: themeStyle.moveButton.color}}
                    text={"Login"}
                />
            </View>
        </SafeAreaView>
    );
}