import React, {useEffect, useState} from "react";
import {ActivityIndicator, FlatList, Text, useColorScheme, View} from "react-native";
import {Colors} from "@/constants/Colors";
import {usePatient} from "@/hooks/usePatient";
import DateTimePicker from '@react-native-community/datetimepicker';
import RadioGroup from "react-native-radio-buttons-group";
import StyledButton from "@/components/StyledButton";
import {insertSymptoms} from "@/constants/insertData";
import {Card} from "@/components/Card";
import {useFunction} from "@/constants/fetchData";
import {SearchBar} from "@/components/SearchBar";
import {searchSymptoms} from "@/constants/searchData";

export default function Symptoms() {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const { patientID } = usePatient();
    const [data, setData] = useState([]);
    const [symptoms, setSymptoms] = useState([]);
    const [confirmed, setConfirmed] = useState(false);
    useFunction(patientID, setData, "getSymptoms");

    useEffect(() => {
        if (data) {
            let seenPatientID = [];
            let seenSymptomDesc = [];
            let tempData = [];
            data.forEach((symptom) => {
                if(!seenSymptomDesc.includes(symptom["symptomDescription"]) || !seenPatientID.includes(symptom.patientID)){
                    seenSymptomDesc.push(symptom["symptomDescription"]);
                    seenPatientID.push(symptom.patientID);
                    tempData.push(symptom);
                }
            });
            setSymptoms(tempData);
        }
    }, [data]);


    const [search, setSearch] = useState("");
    const [loading, setLoading] = useState(true);
    const [desc, setDesc] = useState();
    const [severity, setSeverity] = useState("");
    const [name, setName] = useState("");

    const [symptomName, setSymptomName] = useState('');
    const [symptomDescription, setSymptomDescription] = useState('');
    const [symptomSeverity, setSymptomSeverity] = useState('');
    const [startDate, setStartDate] = useState(new Date());

    const [date, ] = useState(new Date());
    const [show, setShow] = useState(false);

    const onChange = (event, selectedDate) => {
        const currentDate = selectedDate || date;
        setShow(false);
        setStartDate(currentDate);
    };

    const radioButtons = [
        { id: "1", label: "1", value: "1" },
        { id: "2", label: "2", value: "2" },
        { id: "3", label: "3", value: "3" },
        { id: "4", label: "4", value: "4" },
        { id: "5", label: "5", value: "5" },
        { id: "6", label: "6", value: "6" },
        { id: "7", label: "7", value: "7" },
        { id: "8", label: "8", value: "8" },
        { id: "9", label: "9", value: "9" },
        { id: "10", label: "10", value: "10" },
    ];

    return(
        <FlatList
            ListHeaderComponent={
            <>
                <SearchBar
                    icon={true}
                    placeholder={"Search Symptom Name."}
                    value={search}
                    onChangeText={setSearch}
                    onBlur={() => {
                        if(search !== ""){
                            searchSymptoms(patientID, search, setLoading, setName, setDesc, setSeverity)
                        }
                    }}
                />

                {search ? (
                    <ActivityIndicator
                        size={"small"}
                        animating={loading}
                    />
                ): null}

                {search && name && desc && severity ? (
                    <>
                        <Card
                            image={"assessment"}
                            item1={name}
                            item2={desc}
                            quantity={severity}
                            label={"Severity"}
                        />
                        <View style={themeStyle.divider} />
                    </>
                ) : null}
            </>
            }
            ListFooterComponent={
            <>
                <SearchBar
                    style={themeStyle.textInput}
                    placeholder="Enter Symptom Name."
                    value={confirmed ? "" : symptomName}
                    onChangeText={setSymptomName}
                />
                <SearchBar
                    style={themeStyle.textInput}
                    placeholder="Enter Symptom Description."
                    value={confirmed ? "" : symptomDescription}
                    onChangeText={setSymptomDescription}
                />
                <Text style={[themeStyle.textInput, {color: themeStyle.color}]}>
                    Enter Symptom Severity. [1 = lowest, 10 = highest]
                </Text>
                <RadioGroup
                    containerStyle={{flexWrap: "wrap"}}
                    radioButtons={radioButtons}
                    onPress={(selected) => {
                        setSymptomSeverity(selected.toString());
                    }}
                    selectedId={confirmed ? "" : symptomSeverity}
                    layout="row"
                />
                <StyledButton
                    text="Select Start Date"
                    onPress={() => setShow(true)}
                    buttonStyle={{backgroundColor: themeStyle.selectButton.backgroundColor}}
                    textStyle={{color: themeStyle.selectButton.color}}
                />

                {show && (
                    <DateTimePicker
                        value={startDate}
                        mode="date"
                        display="default"
                        onChange={onChange}
                    />
                )}
                <Text style={{textAlign: "center", color: themeStyle.color}}>
                    Start Date Chosen: {startDate.toISOString().split('T')[0]}
                </Text>

                <StyledButton
                    text="Submit Symptom"
                    onPress={()=>{insertSymptoms(patientID, symptomName, symptomDescription, symptomSeverity, startDate, setConfirmed)}}
                    buttonStyle={{backgroundColor: themeStyle.confirmButton.backgroundColor}}
                    textStyle={{color: themeStyle.confirmButton.color}}
                />
            </>
            }
            nestedScrollEnabled={true}
            data={symptoms}
            style={themeStyle}
            renderItem={({ item }) => (
                search && name && item["symptomName"] === name ? null : (
                    <Card
                        image={"assessment"}
                        item1={item["symptomName"]}
                        item2={item["symptomDescription"]}
                        quantity={item["symptomSeverity"]}
                        label={"Severity"}
                    />
                )
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    )
}