import {Alert, StyleProp, StyleSheet, Text, TextStyle, useColorScheme, View,} from 'react-native';
import {useState} from "react";
import {Colors} from "@/constants/Colors";
import StyledButton from "@/components/StyledButton";
import {fetchRequest} from "@/constants/fetchData";

export function AppointmentCard({ data1, data2, item1, item2, item3, request, cancel }) {
    const [disabled, setDisabled] = useState(false);
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;

    const titleStyle: StyleProp<TextStyle> = {
        color: themeStyle.color,
        fontSize: 18,
        fontWeight: "bold",
        textDecorationLine: "underline",
        padding: "2%",
    };
    const textStyle: StyleProp<TextStyle> = {
        color: themeStyle.color,
        fontSize: 16,
        padding: "2%",
    };

    return (
        <View contentContainerStyle={style.container}>
            <View style={style.rowText}>
                <View style={style.columnText1}>
                    <View style={{padding: 3, flex: 1}}>
                        <Text style={titleStyle}>{data1}</Text>
                        <Text style={textStyle}>{data2}</Text>
                    </View>
                </View>
                <View style={[style.columnText2, {flex: 3}]}>
                    <View style={{padding: 3,}}>
                        <Text style={titleStyle}>{item1}</Text>
                        <Text style={textStyle}>{item2}</Text>
                        <Text style={titleStyle}>{item3}</Text>
                    </View>
                </View>
            </View>
            <View style={[style.rowButton]}>
                <View style={style.columnButton}>
                    <StyledButton
                        onPress={() => handleConfirm(request, "Reschedule", setDisabled)}
                        disabled={disabled}
                        buttonStyle={{backgroundColor: themeStyle.rescheduleButton.backgroundColor}}
                        textStyle={{color: themeStyle.rescheduleButton.color}}
                        text={"Reschedule"}
                    />
                </View>
                <View style={style.columnButton}>
                    <StyledButton
                        onPress={() => handleConfirm(cancel, "Cancelled", setDisabled)}
                        disabled={disabled}
                        buttonStyle={{backgroundColor: themeStyle.cancelButton.backgroundColor}}
                        textStyle={{color: themeStyle.cancelButton.color}}
                        text={"Cancel"}
                    />
                </View>
            </View>
        </View>
    );
}

function alertMessage(appointmentID, status, setDisabled, input){
    return Alert.alert("Confirm Appointment Status", "Confirm Appointment is to be " + status + input + "?", [
        {
            text: "Okay",
            onPress: () => {
                console.log(status + " was Confirmed.");
                requestReschedule(appointmentID, status, setDisabled)
            }
        },
        {
            text: "Cancel",
            onPress: () => console.log(status + " was Cancelled.")
        }]
    )
}

function handleConfirm(appointmentID, status, setDisabled) {
    if (status === "Reschedule") {
        alertMessage(appointmentID, status, setDisabled, "d");
    } else if (status === "Cancelled") {
        alertMessage(appointmentID, status, setDisabled, "");
    }
}

function requestReschedule(appointmentID, status, setDisabled) {
    if (status) {
        setReschedule(appointmentID, status).then((response) => {
            if (response.success) {
                if(status === "Reschedule"){
                    Alert.alert("", "Appointment Rescheduled.");
                    console.log("Appointment Reschedule Message:", response.message);
                } else if (status === "Cancelled"){
                    Alert.alert("", "Appointment Cancelled.");
                    setDisabled(true);
                    console.log("Appointment Reschedule Message:", response.message);
                }
            } else {
                Alert.alert("", "Failed to reschedule or cancel appointment.");
                console.log("Appointment Reschedule Failed Message:", response.message);
            }
        }).catch((err) => {
            console.log("Reschedule Error: " + err);
        });
    } else {
        alert("Please upload Document.")
    }
}

async function setReschedule(appointmentID, status) {
    try {
        const formData = new FormData();
        formData.append("action", "setReschedule");
        formData.append("appointmentID", appointmentID);
        formData.append("status", status);
        return await fetchRequest(formData);
    } catch (error){
        console.log(error);
        return;
    }
}

const style = StyleSheet.create({
    container: {
        flexGrow: 1,
        padding: "2%",
        margin: "2%",
    },
    rowText: {
        flexDirection: 'row',
        marginLeft: "2%",
        marginRight: "2%",
        borderRadius: 10,
    },
    columnText1: {
        flexShrink: 1,
        borderWidth: 1,
        borderRightWidth: .5,
        borderRadius: 10,
    },
    columnText2: {
        flexGrow: 1,
        borderWidth: 1,
        borderLeftWidth: .5,
        borderRadius: 10,
    },
    rowButton: {
        flexDirection: 'row',
        borderRadius: 10,
    },
    columnButton: {
        flex: 1,
        borderRadius: 10,
    },
});