import {StyleProp, StyleSheet, Text, TextStyle, useColorScheme, View} from 'react-native';
import {Colors} from "@/constants/Colors";
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import React from "react";

export function Card({ image, item1, item2, item3, quantity, label }) {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;

    const titleStyle: StyleProp<TextStyle> = {
        fontSize: 18,
        color: themeStyle.color,
        fontWeight: "bold",
        textDecorationLine: "underline",
    };

    const textStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
    };

    const labelStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
    };

    const iconStyle: StyleProp<TextStyle> = {
        alignSelf: "center",
        color: themeStyle.color,
    };

    return (
        <View style={[style.container, themeStyle]} testID={"card-container"}>
            <View style={[style.column1, themeStyle]}>
                {image ? <MaterialIcons testID={"card-image"} style={iconStyle} name={image} size={20}/>:null}
            </View>
            <View style={[style.column2, themeStyle]}>
                {item1 ? <Text testID={"card-text1"} style={titleStyle}>{item1}</Text>:null}
                {item2 ? <Text testID={"card-text2"} style={textStyle}>{item2}</Text>:null}
                {item3 ? <Text testID={"card-text3"} style={textStyle}>{item3}</Text>:null}
            </View>
            <View style={[style.column3, themeStyle]}>
                {label && quantity ? <Text testID={"card-label"} style={labelStyle}>{label}</Text>:null}
                {quantity ? <Text testID={"card-quantity"} style={labelStyle}>{quantity}</Text>:null}
            </View>
        </View>
    );
}

const style = StyleSheet.create({
    container: {
        flexDirection: 'row',
        justifyContent: 'space-around',
        alignItems: 'center',
        borderWidth: 1,
        borderRadius: 20,
        padding: "1.5%",
        margin: "2%",
    },
    column1: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    column2: {
        flexGrow: 2,
        justifyContent: 'space-between',
        alignItems: 'center',
    },
    column3: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    text: {
        fontSize: 14,
    },
});