import {StyleProp, StyleSheet, Text, TextStyle, useColorScheme, View} from 'react-native';
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import {openURL} from "expo-linking";
import {Colors} from "@/constants/Colors";
import React from "react";

export function ContactCard({ image, item1, item2, item3, phoneNumber}) {
    let disablePhone = false;
    if(!phoneNumber){
        disablePhone = true;
    }

    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const titleStyle: StyleProp<TextStyle> = {
        fontSize: 18,
        color: themeStyle.color,
        fontWeight: "bold",
        textDecorationLine: "underline",
    };

    const textStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
    };

    const iconStyle: StyleProp<TextStyle> = {
        alignSelf: "center",
        color: themeStyle.color,
    };

    return (
        <View style={[style.container, themeStyle]}>
            <View style={style.column1}>
                {image ? <MaterialIcons testID={"card-image"} style={iconStyle} name={image} size={20}/>:null}
            </View>
            <View style={style.column2}>
                <Text style={titleStyle}>{item1}</Text>
                <Text style={textStyle}>{item2}</Text>
                <Text style={textStyle}>{item3}</Text>
            </View>
            <View style={style.column1}>
                <MaterialIcons
                    name="chat-bubble" size={30}
                    onPress={()=>{makeText(phoneNumber)}}
                    disabled={disablePhone}
                    style={iconStyle}
                />
            </View>
            <View style={style.column1}>
                <MaterialIcons
                    name="videocam" size={30}
                    onPress={()=>{makeVideo(phoneNumber)}}
                    disabled={disablePhone}
                    style={iconStyle}
                />
            </View>
            <View style={style.column1}>
                <MaterialIcons
                    name="phone" size={30}
                    onPress={()=>{makeCall(phoneNumber)}}
                    disabled={disablePhone}
                    style={iconStyle}
                />
            </View>
        </View>
    );
}

function makeText(phoneNumber){
    const openSMS = "sms:" + phoneNumber + "?&body=";
    openURL(openSMS).then(r => console.log(r)).catch((err) => console.log(err));
}

function makeVideo(phoneNumber){
    const openVideo = "https://api.whatsapp.com/send?phone=$" + phoneNumber;
    openURL(openVideo).then(r => console.log(r)).catch((err) => console.log(err));
}

function makeCall(phoneNumber){
    const openCall = "tel:" + phoneNumber;
    openURL(openCall).then(r => console.log(r)).catch((err) => console.log(err));
}

const style = StyleSheet.create({
    container: {
        flexDirection: 'row',
        justifyContent: 'space-around',
        borderWidth: 1,
        borderRadius: 20,
        margin: "1%"
    },
    column1: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    column2: {
        flex: 2,
        paddingLeft: 5,
        justifyContent: 'space-between',
    },
    text: {
        fontSize: 14,
        textAlign: "left",
    },
});