import {Image, ImageStyle, StyleProp, StyleSheet, Text, TextStyle, useColorScheme, View} from 'react-native';
import {Colors} from "@/constants/Colors";
import React from "react";
import {convertBase64ToUri} from "@/constants/fileConversion";
import MaterialIcons from "@expo/vector-icons/MaterialIcons";

export function DocumentCard({ image, item1, item2, item3, quantity, label }) {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;

    const titleStyle: StyleProp<TextStyle> = {
        fontSize: 18,
        color: themeStyle.color,
        fontWeight: "bold",
        textDecorationLine: "underline",
    };

    const textStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
    };

    const labelStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
    };

    const imageStyle: StyleProp<ImageStyle> = {
        width: "100%",
        height: 100,
    };

    const iconStyle: StyleProp<ImageStyle> = {
        alignSelf: "center",
        color: themeStyle.color,
    };

    let imageURI = item3.startsWith('data:image/png;base64,') ? item3 : convertBase64ToUri(item3);
    return (
        <View style={[style.container, themeStyle]}>
            <View style={[style.column1, themeStyle]}>
                {image ? <MaterialIcons testID={"card-image"} style={iconStyle} name={image} size={20}/>:null}
            </View>
            <View style={[style.column2, themeStyle]}>
                <Text style={titleStyle}>{item1}</Text>
                <Text style={textStyle}>{item2}</Text>
                <Image
                    source={imageURI ? { uri: imageURI } : undefined}
                    style={imageStyle}
                />
            </View>
            <View style={[style.column3, themeStyle]}>
                {label && quantity ? <Text testID={"card-label"} style={labelStyle}>{label}</Text>:null}
                {quantity ? <Text testID={"card-quantity"} style={labelStyle}>{quantity === 1 ? "Yes" : "No"}</Text>:null}
            </View>
        </View>
    );
}

const style = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-around',
        alignItems: 'center',
        borderWidth: 1,
        borderRadius: 20,
        margin: "2%",
    },
    column1: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    column2: {
        flexGrow: 2,
        justifyContent: 'space-between',
        alignItems: 'center',
    },
    column3: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
});