import {FlatList} from 'react-native';
import {Card} from "@/components/Card";
import {useEffect, useState} from "react";
import {usePatient} from "@/hooks/usePatient";
import {useFunction} from "@/constants/fetchData";

export function ListData({image, dataPoint1, dataPoint2, dataPoint3, quantity, label, functionName}) {
    const { patientID } = usePatient();
    const [data, setData] = useState([]);
    const [symptoms, setSymptoms] = useState([]);
    useFunction(patientID, setData, functionName);

    useEffect(() => {
        if (data) {
            let seenPatientID = [];
            let seenSymptomDesc = [];
            let tempData = [];
            data.forEach((symptom) => {
                if(!seenSymptomDesc.includes(symptom.symptomDescription) || !seenPatientID.includes(symptom.patientID)){
                    seenSymptomDesc.push(symptom.symptomDescription);
                    seenPatientID.push(symptom.patientID);
                    tempData.push(symptom);
                }
            });
            setSymptoms(tempData);
        }
    }, [data]);

    return (
        <FlatList
            nestedScrollEnabled={true}
            data={data ? functionName === "getSymptoms" ? symptoms : data : data}
            renderItem={({ item }) => (
                <Card
                    image={image}
                    item1={item[dataPoint1]}
                    item2={item[dataPoint2]}
                    item3={item[dataPoint3]}
                    quantity={item[quantity]}
                    label={label}
                />
            )}
            keyExtractor={(item, index) => index.toString()}
        />
    );
}