import {Alert, Modal, Pressable, StyleProp, StyleSheet, Text, useColorScheme, View} from "react-native";
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import React from "react";
import {uploadImage} from "@/constants/handleMedia";
import {Colors} from "@/constants/Colors";

export function MediaModal({image, setImage, isModalOpen, setIsModalOpen }) {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    const modalStyle: StyleProp<any> = {
        backgroundColor: themeStyle.backgroundColor,
        color: themeStyle.color,
    };

    const mediaOptions = [
        { name: "camera", label: "Camera Upload", action: () => uploadImage("camera", setImage, setIsModalOpen) },
        { name: "collections", label: "Gallery Upload", action: () => uploadImage("gallery", setImage, setIsModalOpen) },
        { name: "delete", label: "Delete Image", action: () => handleDelete(image, setImage, setIsModalOpen) },
        { name: "cancel", label: "Cancel", action: () => setIsModalOpen(false) },
    ];

    const handleDelete = (image, setImage, setIsModalOpen) => {
        if(!image) {
            setIsModalOpen(false);
            Alert.alert("Error", "No image selected to delete.");
            return;
        }
        setImage(null);
        setIsModalOpen(false);
    }

    return (
        <Modal
            visible={isModalOpen}
            onRequestClose={() => setIsModalOpen(false)}
            animationType={"slide"}
            presentationStyle={"formSheet"}
        >
            <View style={[modalStyle, style.modalContainer]}>
                {mediaOptions.map(({ name, label, action }) => (
                    <Pressable key={name} onPress={action} style={style.optionItem}>
                        <MaterialIcons name={name} size={50} style={modalStyle}/>
                        <Text style={modalStyle}>{label}</Text>
                    </Pressable>
                ))}
            </View>
        </Modal>
    )
}

const style = StyleSheet.create({
    modalContainer: {
        flex: 1,
        justifyContent: "space-around",
        alignItems: "center",
    },
    optionItem: {
        alignItems: "center",
    }
})

