import {Platform, StyleProp, TextInput, TextStyle, useColorScheme, View} from 'react-native';
import MaterialIcons from "@expo/vector-icons/MaterialIcons";
import {Colors} from "@/constants/Colors";

export function SearchBar({placeholder, onChangeText, value , onPress, onBlur, secureTextEntry = false, textContentType, icon}) {
    const themeStyle = useColorScheme() === "dark" ? Colors.dark : Colors.light;
    let barHeight = Platform ? 50 : 80;

    const textStyle: StyleProp<TextStyle> = {
        fontSize: 16,
        color: themeStyle.color,
        flex: 1,
    };

    const iconStyle: StyleProp<TextStyle> = {
        alignSelf: "center",
        color: themeStyle.color,
    };

    return (
        <View style={style(barHeight).searchBarContainer}>
            {icon ? <MaterialIcons name="search" style={iconStyle} size={20} /> : null}
            <TextInput
                textContentType={textContentType}
                placeholder={placeholder}
                value={value}
                secureTextEntry={secureTextEntry}
                onChangeText={onChangeText}
                onPress={onPress}
                onBlur={onBlur}
                style={textStyle}
            />
        </View>
    );
}

const style = (barHeight) => ({
    searchBarContainer: {
        flexDirection: 'row',
        alignItems: 'center',
        borderRadius: 20,
        borderWidth: 1,
        margin: "2%",
        height: barHeight,
        paddingHorizontal: 10,
    },
});