import {useEffect} from "react";

export async function fetchRequest(formData) {
    const response = await fetch(
        "https://devweb2023.cis.strath.ac.uk/~qrb21125/Project/constants/project.php",
        {
            method: "POST",
            body: formData,
        }
    );
    let data = await response.json();
    if (!data.success || !data.data) {
        return null;
    }
    return data;
}

export function useFunction(patientID, setData, functionName) {
    useEffect(() => {
        if(!patientID){
            setData([]);
            return;
        }

        getData(patientID, functionName).then((response) => {
            if(!response.success){
                setData([]);
                return;
            }
            setData(response.data);
        });
    }, [patientID, functionName, setData]);
}

export const getData = async (patientID, functionName: string) => {
    const formData = new FormData();
    formData.append("action", functionName);
    formData.append("patientID", patientID);
    return await fetchRequest(formData);
};

export function useDoctorFunction(doctorID, setData, functionName){
    useEffect(() => {
        if(!doctorID){
            setData([]);
            return;
        }

        getDoctorData(doctorID, functionName).then((response) => {
            if(!response.success){
                setData([]);
                return;
            }
            setData(response.data);
        });
    }, [doctorID]);
}

export const getDoctorData = async (doctorID, functionName) => {
    const formData = new FormData();
    formData.append("action", functionName);
    formData.append("doctorID", doctorID);
    return await fetchRequest(formData);
};