import {Alert} from "react-native";
import {fetchRequest} from "@/constants/fetchData";

export const getUserData = async (functionName, email, password) => {
    const formData = new FormData();
    formData.append("action", functionName);
    formData.append("email", email);
    formData.append("password", password);
    return await fetchRequest(formData);
}

export function handleLogin(email, password, setPatientID, setDoctorID, setLoading){
    setLoading(true);
    let errors = [];
    if (!email) errors.push("Email is required.");
    if (!password) errors.push("Password is required.");
    const emailRegex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+.[a-zA-Z]{2,}$/;
    if(!emailRegex.test(email)){
        errors.push("Email must be of the format: anything@example.com");
    }
    if (errors.length > 0) {
        Alert.alert("Login Error", errors.join("\n"));
        console.log(errors.join("\n"));
    }
    checkLogin(email, password, setPatientID, setDoctorID)
        .then(_ => {
            console.log("Login check complete. ");
            setLoading(false);
        })
        .catch(_ => {
            console.log("Failed to check login. ");
            setLoading(false);
        });
}

export async function checkLogin(email, password, setPatientID, setDoctorID) {
    const patientResponse = await getUserData("patientLogin", email, password);

    if (patientResponse && patientResponse.success) {
        setDoctorID(null);
        setPatientID(patientResponse.data.patientID);
        return;
    } else {
        console.log("Failed to fetch patient: ", patientResponse);
    }

    const doctorResponse = await getUserData("doctorLogin", email, password);
    if (doctorResponse && doctorResponse.success) {
        setPatientID(null);
        setDoctorID(doctorResponse.data.doctorID);
    } else {
        console.log("Failed to fetch doctor: ", doctorResponse);
    }
}

export const signUpUser = async (name, username, email, password, phoneNumber, doctorType, role, setPatientID, setDoctorID) => {
    const formData = new FormData();
    formData.append("action", "signup");
    formData.append("name", name);
    formData.append("username", username);
    formData.append("email", email);
    formData.append("password", password);
    formData.append("phoneNumber", phoneNumber);
    formData.append("doctorType", doctorType);
    formData.append("role", role);

    const response = await fetch(
        "https://devweb2023.cis.strath.ac.uk/~qrb21125/Project/constants/project.php",
        {
            method: "POST",
            body: formData,
        }
    );

    const data = await response.json();
    if(data.message === "Patient already exists."){
        console.log("Patient already exists.");
    }
    if(data.message === "Doctor already exists."){
        console.log("Doctor already exists.");
    }
    if (data.success === false) {
        console.log("SignUp failed:", data.message);
    }
    await checkLogin(email, password, setPatientID, setDoctorID);
};

export function handleSignUp(name, userName, email, password, phoneNumber, doctorType, role, setPatientID, setDoctorID, setLoading){
    setLoading(true);
    let errors = [];
    if (!name) errors.push("Name is required.");
    if (!userName) errors.push("Username is required.");
    if (!email) errors.push("Email is required.");
    if (!password) errors.push("Password is required.");
    if (!phoneNumber) errors.push("Phone-number is required.");
    if(role === "doctor"){
        if (!doctorType) errors.push("Doctor Type is required.");
    }
    const emailRegex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+.[a-zA-Z]{2,}$/;
    if(!emailRegex.test(email)){
        errors.push("Email must be of the format: anything@example.com");
    }
    const phoneRegex = /^[+]?[(]?[0-9]{3}[)]?[-\s.]?[0-9]{3}[-\s.]?[0-9]{4,6}$/;
    if(!phoneRegex.test(phoneNumber)){
        errors.push("Phone-number must be one of the following formats: +012345678912, 0123456789, +01234567890, 123-123-1234");
    }
    if (errors.length > 0) {
        Alert.alert("Sign Up Error", errors.join("\n"));
        console.log(errors.join("\n"));
    }

    signUpUser(name, userName, email, password, phoneNumber, doctorType, role, setPatientID, setDoctorID)
        .then(_ => {
            console.log("Sign up complete.");
            setLoading(false);
        })
        .catch(_ => {
            console.log("Failed to sign up.");
            setLoading(false);
        });
}
