import * as ImagePicker from "expo-image-picker";
import {CameraType, ImagePickerCanceledResult, ImagePickerSuccessResult} from "expo-image-picker";

// https://www.youtube.com/watch?v=uX5E_QFJubU&t=15s
export async function uploadImage(mode, setImage, setIsModalOpen){
    try {
        let result : ImagePickerSuccessResult | ImagePickerCanceledResult = {canceled: true, assets: null};
        switch (mode) {
            case "camera":
                const cameraPermission = await ImagePicker.requestCameraPermissionsAsync();
                if (!cameraPermission.granted) {
                    alert("Camera access is required to upload a profile picture.");
                    return;
                }
                result = await ImagePicker.launchCameraAsync({
                    cameraType: CameraType.back,
                    allowsEditing: true,
                    quality: 1,
                });
                break;
            case "gallery":
                const galleryPermission = await ImagePicker.requestMediaLibraryPermissionsAsync();
                if (!galleryPermission.granted) {
                    alert("Gallery access is required to upload a profile picture.");
                    return;
                }
                result = await ImagePicker.launchImageLibraryAsync({
                    mediaTypes: ImagePicker.MediaTypeOptions.Images,
                    allowsEditing: true,
                    quality: 1,
                });
                break;
            default:
                console.log("Invalid mode provided");
                return;
        }

        if (!result.canceled) {
            console.log("Image selected: ", result.assets[0].uri);
            setImage(result.assets[0].uri);
            setIsModalOpen(false);
            return;
        }
        console.log("Image selection canceled");
        setIsModalOpen(false);
    } catch (e){
        console.log(`Error while uploading image in ${mode} mode:`, e);
    }
}
