import {Alert} from "react-native";
import {fetchRequest} from "@/constants/fetchData";

export async function insertDocumentFetch(patientID, documentURI) {
    const formData = new FormData();
    formData.append("action", "insertDocuments");
    formData.append("patientID", patientID);
    formData.append("documentFile", {
        uri: documentURI,
        type: "image/jpeg",
        name: "documentFile",
    });
    return await fetchRequest(formData);
}

async function insertSymptomsFetch(patientID, symptomName, symptomDescription, symptomSeverity, startDate) {
    try{
        const formData = new FormData();
        formData.append("action", "insertSymptoms");
        formData.append("patientID", patientID);
        formData.append("symptomName", symptomName);
        formData.append("symptomDescription", symptomDescription);
        formData.append("symptomSeverity", symptomSeverity);
        formData.append("startDate", startDate);
        return await fetchRequest(formData);
    } catch (error) {
        console.log(error);
        return;
    }
}

export function insertSymptoms(patientID, symptomName, symptomDescription, symptomSeverity, startDate, setConfirmed) {
    let errors = [];
    if (!symptomName) errors.push("Symptom name is required.");
    if (!symptomDescription) errors.push("Symptom description is required.");
    if (!symptomSeverity) errors.push("Symptom severity is required.");
    if (!startDate) errors.push("Start date is required.");
    if (errors.length > 0) {
        Alert.alert("Missing Inputs", errors.join("\n"));
        console.log(errors.join("\n"));
    }

    insertSymptomsFetch(patientID, symptomName, symptomDescription, symptomSeverity, startDate)
        .then((data) => {
            Alert.alert("", "Symptoms inserted successfully.");
            console.log("Symptoms inserted successfully.", data);
            setConfirmed(true);
        })
        .catch((error) => {
            Alert.alert("","Error inserting symptoms.");
            console.error("Error inserting symptoms: ", error);
        });
}