import {convertBase64ToUri} from "@/constants/fileConversion";
import {fetchRequest} from "@/constants/fetchData";

async function searchDocumentsFetch(patientID, search) {
    const formData = new FormData();
    formData.append("action", "searchDocuments");
    formData.append("patientID", patientID);
    formData.append("documentTitle", search);
    return await fetchRequest(formData);
}

export function searchDocuments(patientID, search, setLoading, setDocTitle, setDocDesc, setDocType, setDocFile, setFollowUp) {
    searchDocumentsFetch(patientID, search)
        .then(data => {
            setDocTitle(data.data.documentTitle);
            setDocDesc(data.data["documentDescription"]);
            setDocType(data.data.documentType);
            if (data && data.data["documentFile"]) {
                let uri = convertBase64ToUri(data.data["documentFile"]);
                setDocFile(uri);
            }
            setFollowUp(data.data["followUp"]);
            setLoading(false);
        })
        .catch(e => {
            console.log("Documents Not Found: ", e);
            setDocTitle("");
        });
}

async function searchAppointmentsFetch(patientID, search) {
    const formData = new FormData();
    formData.append("action", "searchAppointments");
    formData.append("patientID", patientID);
    formData.append("title", search);
    return await fetchRequest(formData);
}

export function searchAppoints(patientID, search, setLoading, setAppointmentDate, setAppointmentTime, setTitle, setDescription, setLocation) {
    if(patientID && search){
        searchAppointmentsFetch(patientID, search)
            .then((data) => {
                console.log("Appointment Data Found: ", data);
                setAppointmentDate(data.data.appointmentDate);
                setAppointmentTime(data.data.appointmentTime);
                setTitle(data.data.title);
                setDescription(data.data.description);
                setLocation(data.data.location);
                setLoading(false);
            })
            .catch(error => {
                console.log("Failed to Search Appointments: ", error);
                setAppointmentTime(null);
            });
    }
}

async function searchMedsFetch(patientID, search) {
    const formData = new FormData();
    formData.append("action", "searchMedications");
    formData.append("patientID", patientID);
    formData.append("medicationName", search);
    return await fetchRequest(formData);
}

export function searchMeds(patientID, search, setLoading, setMedicationName, setStrength, setType, setQuantity) {
    searchMedsFetch(patientID, search)
        .then((data) => {
            console.log("Medication Found: ", data);
            setMedicationName(data.data.medicationName);
            setStrength(data.data.strength);
            setType(data.data.type);
            setQuantity(data.data["quantityAvailable"]);
            setLoading(false);
        })
        .catch(e => {
            console.log("Medication Not Found: ", e);
            setMedicationName(null);
        });
}

async function searchNotifsFetch(patientID, search) {
    const formData = new FormData();
    formData.append("action", "searchNotifications");
    formData.append("patientID", patientID);
    formData.append("subject", search);
    return await fetchRequest(formData);
}

export function searchNotifs(patientID, search, setLoading, setNotificationTime, setSubject, setDescription) {
    searchNotifsFetch(patientID, search)
        .then(data => {
            console.log("Notifications Found: ", data)
            setNotificationTime(data.data.notificationTime)
            setSubject(data.data.subject);
            setDescription(data.data.description);
            setLoading(false);
        })
        .catch(e => {
            console.log("Notifications Not Found: ", e);
            setSubject(null);
        });
}

async function searchSymptomsFetch(patientID, symptomName) {
    const formData = new FormData();
    formData.append("action", "searchSymptoms");
    formData.append("patientID", patientID);
    formData.append("symptomName", symptomName);
    return await fetchRequest(formData);
}

export function searchSymptoms(patientID, search, setLoading, setName, setDesc, setSeverity) {
    searchSymptomsFetch(patientID, search)
        .then(data => {
            console.log("Symptoms Found: ", data)
            setName(data.data.symptomName)
            setDesc(data.data.symptomDescription);
            setSeverity(data.data.symptomSeverity);
            setLoading(false);
        })
        .catch(e => {
            console.log("Symptoms Not Found: ", e);
            setName(null);
        });
}

async function searchContactsFetch(search) {
    const formData = new FormData();
    formData.append("action", "searchContacts");
    formData.append("doctorName", search);
    return await fetchRequest(formData);
}

export function searchContacts(search, setLoading, setDoctorName, setDoctorType, setPhoneNumber) {
    searchContactsFetch(search)
        .then(data => {
            console.log("Contacts Found: ", data)
            setDoctorName(data.data['doctorName']);
            setDoctorType(data.data['doctorType']);
            setPhoneNumber(data.data.phoneNumber);
            setLoading(false);
        })
        .catch(e => {
            console.log("Contacts Not Found: ", e);
            setDoctorName(null);
        });
}